@@ -1,11 +1,11 @@
 #!/bin/sh
-export PATH='/usr/obj/ports/hscolour-1.23/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
+export PATH='/usr/obj/ports/hscolour-1.24/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: hscolour
-version: 1.23
-id: hscolour-1.23-94025b845be4dd30f90fee5c1b9d75f8
-key: hscol_D9eX1LEa8SaE1RFFjW0myg
+version: 1.24
+id: hscolour-1.24-2INJ3Qyba2w3oVHuiH7YLO
+key: hscolour-1.24-2INJ3Qyba2w3oVHuiH7YLO
 license: GPL
-copyright: 2003-2015 Malcolm Wallace; 2006 Bjorn Bringert
+copyright: 2003-2016 Malcolm Wallace; 2006 Bjorn Bringert
 maintainer: Malcolm Wallace
 homepage: http://code.haskell.org/~malcolm/hscolour/
 synopsis: Colourise Haskell code.
@@ -22,9 +22,10 @@ description:
 category: Language
 author: Malcolm Wallace
 exposed: True
+indefinite: False
 exposed-modules:
-    Language.Haskell.HsColour Language.Haskell.HsColour.ANSI
-    Language.Haskell.HsColour.Anchors Language.Haskell.HsColour.ACSS
+    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
+    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
     Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
     Language.Haskell.HsColour.ColourHighlight
     Language.Haskell.HsColour.Colourise
@@ -32,14 +33,18 @@ exposed-modules:
     Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
     Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
     Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
+abi: 472a86db9e657abba8d7ac5128690cee
 trusted: False
-import-dirs: /usr/local/lib/ghc/hscolour-1.23
-library-dirs: /usr/local/lib/ghc/hscolour-1.23
-data-dir: /usr/local/share/hs-hscolour-1.23
-hs-libraries: HShscolour-1.23-D9eX1LEa8SaE1RFFjW0myg
+import-dirs: /usr/local/lib/ghc/hscolour-1.24
+library-dirs: /usr/local/lib/ghc/hscolour-1.24
+              /usr/local/lib/x86_64-openbsd-ghc-8.2.2
+data-dir: /usr/local/share/hs-hscolour-1.24
+hs-libraries: HShscolour-1.24-2INJ3Qyba2w3oVHuiH7YLO
 depends:
-    base-4.8.2.0-6d41353bf1900ecbb9b02a306c286c36
-    containers-0.5.6.2-72662c7d6dea4fa8c95128efb85ebc60
-haddock-interfaces: /usr/local/share/doc/hs-hscolour-1.23/html/hscolour.haddock
-haddock-html: /usr/local/share/doc/hs-hscolour-1.23/html
+    base-4.10.1.0 containers-0.5.10.2
+abi-depends: base-4.10.1.0=3319c96bc0bdd0e7df6bb89e8bc8756b
+             containers-0.5.10.2=3a910cd7b137e6ec964a6149559bd205
+haddock-interfaces: /usr/local/share/doc/hs-hscolour-1.24/html/hscolour.haddock
+haddock-html: /usr/local/share/doc/hs-hscolour-1.24/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
+
